# LaTeX Book Template – Manning Style  

A LaTeX template that mimics the professional book style of Manning Publications. While every effort has been made to emulate the layout, please note that some fonts, colors, and spacing may not be identical to Manning books. The purpose of this template is to provide a primitive layout using the right package stack, serving as a solid foundation for further customizations and refinements to suit your needs.

## Features  
- Structured chapter layouts and professional design.  
- Full support for code snippets, mathematical equations, and figures.  
- Customizable styling to fit your book's specific needs.  
- Pre-configured environments for seamless typesetting.   
- Compatibility with commonly used LaTeX packages.  

## Recommended Compiler  
This template is optimized for **LuaLaTeX** to ensure proper handling of fonts, modern features, and compatibility with the included packages.  

## Packages Used  
This template leverages the following LaTeX packages:  
- **tikz**: A powerful tool for creating diagrams and illustrations directly in LaTeX. 
- **fontspec**: Provides access to system-installed fonts, offering modern font management. 
- **tabularray**: Simplifies table creation with modern syntax and styling options.  
- **titlesec**: Allows advanced customization of section and chapter titles.  
- **mdframed**: Used for creating framed environments, perfect for highlighting content like definitions or notes.  
- **array**: Enhances table functionality and customization.  
- **caption**: Customizes captions for figures, tables, and other floating environments.  
- **pdfpages**: Facilitates the inclusion of external PDF files into your document.  
- **svg**: Enables direct inclusion of scalable vector graphics (SVG) files in your project.  
- **etoolbox**: Provides advanced programming tools for conditional commands and package configuration.  
- **imakeidx**: Simplifies the creation of indices for your book.  

## Getting Started  

### Prerequisites  
Ensure you have the following installed:  
- A LaTeX distribution (e.g., [TeX Live](https://www.tug.org/texlive/), [MikTeX](https://miktex.org/), or [MacTeX](https://tug.org/mactex/)).  
- A text editor or LaTeX IDE (e.g., [Overleaf](https://overleaf.com), [Texmaker](https://www.xm1math.net/texmaker/), or [VS Code](https://code.visualstudio.com/) with LaTeX extensions).  

### Installation  
1. Clone this repository:  
   ```bash  
   git clone https://github.com/Ammar-Taha/Manning-Book-Temp.git  
   ```  
2. Open the project folder in your LaTeX editor or IDE.  
3. Compile the `main.tex` file using **LuaLaTeX**.  

## How to Use  
- Modify the `main.tex` file to start writing your content.  
- Customize the title, author, and other metadata in the preamble.  
- Use the pre-configured environments for code snippets, equations, and figures.  
- Refer to the sample chapters included for examples of usage.  

## Example Output  
For a preview of the template's output, see the [`main.pdf`](./main.pdf) file.  

## License  
This project is licensed under the MIT License. For more information, see the [`LICENSE`](./LICENSE) file. 

## Contact  
For questions or feedback, feel free to connect with me on <a href="https://www.linkedin.com/in/ammar-taha/" target="_blank">LinkedIn</a>.  
